@@ -1,10 +1,7 @@
 from adaptiq.core.abstract.q_table.base_q_table_manager import BaseQTableManager
-from adaptiq.core.abstract.q_table.base_state_action_extractor import (
-    BaseStateActionExtractor,
-)
 from adaptiq.core.abstract.q_table.base_state_mapper import BaseStateMapper
 
 # from adaptiq.core.abstract.pipelines.base_pre_run import BasePreRun
 # from adaptiq.core.abstract.pipelines.base_post_run import BasePostRun
 
-__all__ = ["BaseQTableManager", "BaseStateActionExtractor", "BaseStateMapper"]
+__all__ = ["BaseQTableManager", "BaseStateMapper"]
